@@ -102,7 +102,7 @@ def show_works(req):
     print(work_ids)
 
 
-reqs = get_requests(request_id=211, with_detail=True, with_metadata=True)
+reqs = get_requests(request_id=538, with_detail=True, with_metadata=True)
 for req in reqs:
     # print(req['request_id'])
     # print(rets)
@@ -126,14 +126,14 @@ sys.exit(0)
 
 """
 
-tfs = get_transforms(request_id=205)
+tfs = get_transforms(request_id=219)
 for tf in tfs:
     # print(tf)
     # print(tf['transform_metadata']['work'].to_dict())
-    print(json_dumps(tf, sort_keys=True, indent=4))
+    # print(json_dumps(tf, sort_keys=True, indent=4))
     pass
 
-sys.exit(0)
+# sys.exit(0)
 
 """
 msgs = retrieve_messages(workload_id=25972557)
@@ -154,7 +154,7 @@ print(number_contents)
 sys.exit(0)
 """
 
-prs = get_processings(request_id=205)
+prs = get_processings(request_id=219)
 i = 0
 for pr in prs:
     # if pr['request_id'] == 91:
